from .base import BakeryBase
from rest_framework.response import Response
from issuestracker.models import Category, Candidate
from issuestracker.serializers.bakery.CategoryPage import CategorySerializer


class BakeryCategory(BakeryBase):
    def get(self, request, category=None):
        return Response(
            {
                "candidate_count": Candidate.objects.count(),
                "categories": CategorySerializer(
                    Category.live.get(slug=self.kwargs["category"])
                ).data,
            }
        )



from rest_framework import serializers
from issuestracker.models import Faq, Story, Position, Issue


class PositionSerializer(serializers.ModelSerializer):
    candidates = serializers.SerializerMethodField()

    def get_candidates(self, obj):
        return [candidate.slug for candidate in obj.candidates.all()]

    class Meta:
        model = Position
        fields = ("name", "explanation", "candidates")


class FaqSerializer(serializers.ModelSerializer):
    class Meta:
        model = Faq
        fields = ("question", "answer")


class StorySerializer(serializers.ModelSerializer):
    class Meta:
        model = Story
        fields = ("headline", "link")


class IssueSerializer(serializers.ModelSerializer):
    category = serializers.SerializerMethodField()
    category_slug = serializers.SerializerMethodField()
    faq_set = FaqSerializer(many=True, read_only=True)
    story_set = StorySerializer(many=True, read_only=True)
    position_set = PositionSerializer(many=True, read_only=True)

    def get_category(self, obj):
        return str(obj.category)

    def get_category_slug(self, obj):
        return obj.category.slug

    class Meta:
        model = Issue
        fields = (
            "name",
            "slug",
            "category",
            "category_slug",
            "summary",
            "faq_set",
            "story_set",
            "position_set",
        )



from rest_framework import serializers
from issuestracker.models import Category, Issue


class IssueSerializer(serializers.ModelSerializer):
    position_count = serializers.SerializerMethodField()
    candidates_with_position_count = serializers.SerializerMethodField()

    def get_position_count(self, obj):
        return obj.position_set.all().count()

    def get_candidates_with_position_count(self, obj):
        count = 0
        for position in obj.position_set.all():
            count += position.candidates.count()

        return count

    class Meta:
        model = Issue
        fields = (
            "name",
            "slug",
            "position_count",
            "candidates_with_position_count",
        )


class CategorySerializer(serializers.ModelSerializer):
    issue_set = IssueSerializer(many=True, read_only=True)

    class Meta:
        model = Category
        fields = ("name", "slug", "icon", "summary", "issue_set")



from .base import BakeryBase
from rest_framework.response import Response
from issuestracker.models import Issue
from issuestracker.serializers.bakery.IssuePage import IssueSerializer


class BakeryIssue(BakeryBase):
    def get(self, request, issue=None):
        return Response(
            {
                "candidates": self.get_all_candidates(),
                "issue": IssueSerializer(
                    Issue.live.get(slug=self.kwargs["issue"])
                ).data,
            }
        )
